ReceiptRuleSetStore

Struct ReceiptRuleSetStore 

pub struct ReceiptRuleSetStore { /* private fields */ }
Store for receipt rule sets and rules.

Receipt rules are accepted and stored but never actually process incoming email. This is for API compatibility only.

Implementations

Source

impl ReceiptRuleSetStore

pub fn new() -> Self

Create a new empty receipt rule set store.

pub fn create_rule_set(&self, name: &str) -> Result<(), SesError>

Create a new receipt rule set.

Errors

Returns AlreadyExistsException if a rule set with the same name exists.

pub fn delete_rule_set(&self, name: &str) -> Result<(), SesError>

Delete a receipt rule set.

Errors

Returns RuleSetDoesNotExistException if not found.

pub fn describe_rule_set( &self, name: &str, ) -> Result<ReceiptRuleSetRecord, SesError>

Describe a receipt rule set.

Errors

Returns RuleSetDoesNotExistException if not found.

pub fn create_rule( &self, rule_set_name: &str, rule: ReceiptRule, after: Option<&str>, ) -> Result<(), SesError>

Create a receipt rule within a rule set.

Errors

Returns RuleSetDoesNotExistException if the rule set is not found.

pub fn delete_rule( &self, rule_set_name: &str, rule_name: &str, ) -> Result<(), SesError>

Delete a receipt rule from a rule set.

Errors

Returns RuleSetDoesNotExistException if the rule set is not found.

pub fn clone_rule_set( &self, source_name: &str, dest_name: &str, ) -> Result<(), SesError>

Clone a receipt rule set to a new name.

Errors

Returns RuleSetDoesNotExistException if the source does not exist. Returns AlreadyExistsException if the destination already exists.

pub fn get_active_rule_set( &self, ) -> Option<(ReceiptRuleSetMetadata, Vec<ReceiptRule>)>

Get the active receipt rule set name and metadata.

pub fn set_active_rule_set(&self, name: Option<&str>) -> Result<(), SesError>

Set the active receipt rule set.

Errors

Returns RuleSetDoesNotExistException if the rule set is not found (when a name is provided).